@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 import os
 from functools import partial, wraps
-from .common import PyEXception, _interval, _getJson, _USAGE_TYPES
+from .common import PyEXception, _interval
+from .account import messageBudget, metadata, metadataDF, \
+    usage, usageDF
 from .alternative import crypto, cryptoDF, \
     sentiment, sentimentDF, \
     ceoCompensation, ceoCompensationDF
@@ -94,9 +96,11 @@ from .refdata import symbols, iexSymbols, mutualFundSymbols, otcSymbols, interna
     directory, directoryDF, \
     calendar, calendarDF, holidays, holidaysDF, \
     exchanges, exchangesDF, \
+    figi, figiDF, \
     internationalExchanges, internationalExchangesDF, \
     sectors, sectorsDF, \
     tags, tagsDF
+from .rules import schema, create, lookup, pause, resume, delete
 from .stats import stats, statsDF, \
     recent, recentDF, \
     records, recordsDF, \
@@ -156,6 +160,7 @@ from .stocks import advancedStats, advancedStatsDF, \
     stockSplits, stockSplitsDF, \
     tenQ, tenK, \
     threshold, thresholdDF, \
+    technicals, technicalsDF, \
     timeSeriesInventory, timeSeries, \
     timeSeriesInventoryDF, timeSeriesDF, \
     upcomingEvents, upcomingEventsDF, \
@@ -168,7 +173,7 @@ from .stocks import advancedStats, advancedStatsDF, \
 from .options import optionExpirations, options, optionsDF
 
 try:
-    from .studies import peerCorrelation, bollinger, dema, ema, sar, sma
+    from .studies import peerCorrelation, bollinger, dema, ema, sar, sma, rsi
 
 except ImportError:
     peerCorrelation = None
@@ -177,10 +182,19 @@ except ImportError:
     ema = None
     sar = None
     sma = None
+    rsi = None
+
 
 DEFAULT_API_LIMIT = 5
 
 _INCLUDE_FUNCTIONS = [
+    # Rules
+    ('schema', schema),
+    ('createRule', create),
+    ('lookupRule', lookup),
+    ('pauseRule', pause),
+    ('resumeRule', resume),
+    ('deleteRule', delete),
     # Refdata
     ('symbols', symbols),
     ('iexSymbols', iexSymbols),
@@ -217,6 +231,8 @@ _INCLUDE_FUNCTIONS = [
     ('holidaysDF', holidaysDF),
     ('exchanges', exchanges),
     ('exchangesDF', exchangesDF),
+    ('figi', figi),
+    ('figiDF', figiDF),
     ('internationalExchanges', internationalExchanges),
     ('internationalExchangesDF', internationalExchangesDF),
     ('sectors', sectors),
@@ -358,6 +374,8 @@ _INCLUDE_FUNCTIONS = [
     ('stockSplitsDF', stockSplitsDF),
     ('tenQ', tenQ),
     ('tenK', tenK),
+    ('technicals', technicals),
+    ('technicalsDF', technicalsDF),
     ('timeSeriesInventory', timeSeriesInventory),
     ('timeSeriesInventoryDF', timeSeriesInventoryDF),
     ('timeSeries', timeSeries),
@@ -406,6 +424,12 @@ _INCLUDE_FUNCTIONS = [
     ('tradeBreakDF', tradeBreakDF),
     ('tradingStatus', tradingStatus),
     ('tradingStatusDF', tradingStatusDF),
+    # Account
+    ('messageBudget', messageBudget),
+    ('metadata', metadata),
+    ('metadataDF', metadataDF),
+    ('usage', usage),
+    ('usageDF', usageDF),
     # Alternative
     ('crypto', crypto),
     ('cryptoDF', cryptoDF),
@@ -611,6 +635,7 @@ _INCLUDE_STUDIES = [
     ('ema', ema),
     ('sar', sar),
     ('sma', sma),
+    ('rsi', rsi),
 ]
 
 
@@ -665,15 +690,8 @@ class Client(object):
             raise PyEXception('Must provide method!')
         return meth(token=self._token, version=self._version, *args, **kwargs)
 
-    def account(self):
-        return _getJson('account/metadata', self._token, self._version)
-
-    def usage(self, type=None):
-        if type:
-            if type not in _USAGE_TYPES:
-                raise PyEXception('type not recognized: {}'.format(type))
-            return _getJson('account/usage/{type}'.format(type=type), self._token, self._version)
-        return _getJson('account/usage/messages', self._token, self._version)
+    def account(self, *args, **kwargs):
+        return self.metadata(*args, **kwargs)
 
 
 #############################
