@@ -24,6 +24,9 @@ def _baseDF(id, symbol='', **kwargs):
 def brain30DaySentiment(symbol='', **kwargs):
     '''Brain Company’s Sentiment Indicator monitors the stock sentiment from the last 30 days of public financial news for about 3,500 US stocks. The sentiment scoring technology is based on a combination of various natural language processing techniques. The sentiment score assigned to each stock is a value ranging from -1 (most negative) to +1 (most positive) that is updated daily.
     https://iexcloud.io/docs/api/#brain-companys-30-day-sentiment-indicator
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_SENTIMENT_30_DAYS', symbol=symbol, **kwargs)
 
@@ -32,6 +35,9 @@ def brain30DaySentiment(symbol='', **kwargs):
 def brain30DaySentimentDF(symbol='', **kwargs):
     '''Brain Company’s Sentiment Indicator monitors the stock sentiment from the last 30 days of public financial news for about 3,500 US stocks. The sentiment scoring technology is based on a combination of various natural language processing techniques. The sentiment score assigned to each stock is a value ranging from -1 (most negative) to +1 (most positive) that is updated daily.
     https://iexcloud.io/docs/api/#brain-companys-30-day-sentiment-indicator
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_SENTIMENT_30_DAYS', symbol=symbol, **kwargs)
 
@@ -40,6 +46,9 @@ def brain30DaySentimentDF(symbol='', **kwargs):
 def brain7DaySentiment(symbol='', **kwargs):
     '''Brain Company’s Sentiment Indicator monitors the stock sentiment from the last 7 days of public financial news for about 3,500 US stocks. The sentiment scoring technology is based on a combination of various natural language processing techniques. The sentiment score assigned to each stock is a value ranging from -1 (most negative) to +1 (most positive) that is updated daily.
     https://iexcloud.io/docs/api/#brain-companys-7-day-sentiment-indicator
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_SENTIMENT_7_DAYS', symbol=symbol, **kwargs)
 
@@ -48,6 +57,9 @@ def brain7DaySentiment(symbol='', **kwargs):
 def brain7DaySentimentDF(symbol='', **kwargs):
     '''Brain Company’s Sentiment Indicator monitors the stock sentiment from the last 7 days of public financial news for about 3,500 US stocks. The sentiment scoring technology is based on a combination of various natural language processing techniques. The sentiment score assigned to each stock is a value ranging from -1 (most negative) to +1 (most positive) that is updated daily.
     https://iexcloud.io/docs/api/#brain-companys-7-day-sentiment-indicator
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_SENTIMENT_7_DAYS', symbol=symbol, **kwargs)
 
@@ -56,6 +68,9 @@ def brain7DaySentimentDF(symbol='', **kwargs):
 def brain21DayMLReturnRanking(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 21 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-21-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_RANKING_21_DAYS', symbol=symbol, **kwargs)
 
@@ -64,6 +79,9 @@ def brain21DayMLReturnRanking(symbol='', **kwargs):
 def brain21DayMLReturnRankingDF(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 21 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-21-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_RANKING_21_DAYS', symbol=symbol, **kwargs)
 
@@ -72,6 +90,9 @@ def brain21DayMLReturnRankingDF(symbol='', **kwargs):
 def brain10DayMLReturnRanking(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-10-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_RANKING_10_DAYS', symbol=symbol, **kwargs)
 
@@ -80,6 +101,9 @@ def brain10DayMLReturnRanking(symbol='', **kwargs):
 def brain10DayMLReturnRankingDF(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-10-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_RANKING_10_DAYS', symbol=symbol, **kwargs)
 
@@ -88,6 +112,9 @@ def brain10DayMLReturnRankingDF(symbol='', **kwargs):
 def brain5DayMLReturnRanking(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-5-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_RANKING_5_DAYS', symbol=symbol, **kwargs)
 
@@ -96,6 +123,9 @@ def brain5DayMLReturnRanking(symbol='', **kwargs):
 def brain5DayMLReturnRankingDF(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-5-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_RANKING_5_DAYS', symbol=symbol, **kwargs)
 
@@ -104,6 +134,9 @@ def brain5DayMLReturnRankingDF(symbol='', **kwargs):
 def brain3DayMLReturnRanking(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-3-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_RANKING_3_DAYS', symbol=symbol, **kwargs)
 
@@ -112,6 +145,9 @@ def brain3DayMLReturnRanking(symbol='', **kwargs):
 def brain3DayMLReturnRankingDF(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-3-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_RANKING_3_DAYS', symbol=symbol, **kwargs)
 
@@ -120,6 +156,9 @@ def brain3DayMLReturnRankingDF(symbol='', **kwargs):
 def brain2DayMLReturnRanking(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-2-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_RANKING_2_DAYS', symbol=symbol, **kwargs)
 
@@ -128,6 +167,9 @@ def brain2DayMLReturnRanking(symbol='', **kwargs):
 def brain2DayMLReturnRankingDF(symbol='', **kwargs):
     '''Brain Company’s Machine Learning proprietary platform is used to generate a daily stock ranking based on the predicted future returns of a universe of around 1,000 stocks over 10 days. The model implements a voting scheme of machine learning classifiers that non linearly combine a variety of features with a series of techniques aimed at mitigating the well-known overfitting problem for financial data with a low signal to noise ratio.
     https://iexcloud.io/docs/api/#brain-companys-2-day-machine-learning-estimated-return-ranking
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_RANKING_2_DAYS', symbol=symbol, **kwargs)
 
@@ -136,6 +178,9 @@ def brain2DayMLReturnRankingDF(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilingsAll(symbol='', **kwargs):
     '''Metrics about the language used in a company’s most recent annual or quarterly filings (10Ks and 10Qs). Includes metrics on the financial sentiment and the scores based on the prevalence of words in the statement categorized into four themes: constraining language, interesting language, litigious language, and language indicating uncertainty.
     https://iexcloud.io/docs/api/#brain-companys-language-metrics-on-company-filings-quarterly-and-annual
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_LANGUAGE_METRICS_ALL', symbol=symbol, **kwargs)
 
@@ -144,6 +189,9 @@ def brainLanguageMetricsOnCompanyFilingsAll(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilingsAllDF(symbol='', **kwargs):
     '''Metrics about the language used in a company’s most recent annual or quarterly filings (10Ks and 10Qs). Includes metrics on the financial sentiment and the scores based on the prevalence of words in the statement categorized into four themes: constraining language, interesting language, litigious language, and language indicating uncertainty.
     https://iexcloud.io/docs/api/#brain-companys-language-metrics-on-company-filings-quarterly-and-annual
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_LANGUAGE_METRICS_ALL', symbol=symbol, **kwargs)
 
@@ -152,6 +200,9 @@ def brainLanguageMetricsOnCompanyFilingsAllDF(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilings(symbol='', **kwargs):
     '''Metrics about the language used in a company’s most recent annual filing (10Ks). Includes metrics on the financial sentiment and the scores based on the prevalence of words in the statement categorized into four themes: constraining language, interesting language, litigious language, and language indicating uncertainty.
     https://iexcloud.io/docs/api/#brain-companys-language-metrics-on-company-filings-annual-only
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_LANGUAGE_METRICS_10K', symbol=symbol, **kwargs)
 
@@ -160,6 +211,9 @@ def brainLanguageMetricsOnCompanyFilings(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilingsDF(symbol='', **kwargs):
     '''Metrics about the language used in a company’s most recent annual filing (10Ks). Includes metrics on the financial sentiment and the scores based on the prevalence of words in the statement categorized into four themes: constraining language, interesting language, litigious language, and language indicating uncertainty.
     https://iexcloud.io/docs/api/#brain-companys-language-metrics-on-company-filings-annual-only
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_LANGUAGE_METRICS_10K', symbol=symbol, **kwargs)
 
@@ -168,6 +222,9 @@ def brainLanguageMetricsOnCompanyFilingsDF(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilingsDifferenceAll(symbol='', **kwargs):
     '''Compares Brain’s sentiment and language metrics from the company’s most recent repot (annual or quarterly) to the report from last year (10Ks) or the corresponding quarter the prior year (10Qs).
     https://iexcloud.io/docs/api/#brain-companys-differences-in-language-metrics-on-company-filings-quarterly-and-annual-from-prior-period
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_LANGUAGE_DIFFERENCES_ALL', symbol=symbol, **kwargs)
 
@@ -176,6 +233,9 @@ def brainLanguageMetricsOnCompanyFilingsDifferenceAll(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilingsDifferenceAllDF(symbol='', **kwargs):
     '''Compares Brain’s sentiment and language metrics from the company’s most recent repot (annual or quarterly) to the report from last year (10Ks) or the corresponding quarter the prior year (10Qs).
     https://iexcloud.io/docs/api/#brain-companys-differences-in-language-metrics-on-company-filings-quarterly-and-annual-from-prior-period
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_LANGUAGE_DIFFERENCES_ALL', symbol=symbol, **kwargs)
 
@@ -184,6 +244,9 @@ def brainLanguageMetricsOnCompanyFilingsDifferenceAllDF(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilingsDifference(symbol='', **kwargs):
     '''Compares Brain’s sentiment and language metrics from the company’s most recent annual filing (10K) to the report from last year.
     https://iexcloud.io/docs/api/#brain-companys-differences-in-language-metrics-on-company-annual-filings-from-prior-year
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_BRAIN_LANGUAGE_DIFFERENCES_10K', symbol=symbol, **kwargs)
 
@@ -192,5 +255,8 @@ def brainLanguageMetricsOnCompanyFilingsDifference(symbol='', **kwargs):
 def brainLanguageMetricsOnCompanyFilingsDifferenceDF(symbol='', **kwargs):
     '''Compares Brain’s sentiment and language metrics from the company’s most recent annual filing (10K) to the report from last year.
     https://iexcloud.io/docs/api/#brain-companys-differences-in-language-metrics-on-company-annual-filings-from-prior-year
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_BRAIN_LANGUAGE_DIFFERENCES_10K', symbol=symbol, **kwargs)
