@@ -25,6 +25,9 @@ def kScore(symbol='', **kwargs):
     '''Kavout takes in over 200 factors and signals including fundamentals, pricing, technical indicators, and alternative data, and then uses an ensemble machine learning technique to analyze and rank stocks.
     K Score is a stock rating and ranking score with values ranging from 1-to-9. A higher K Score (7-9) assigned to a stock indicates a higher probability of outperformance, whereas a lower K Score (1-3) indicates a lower probability of outperformance in the next month.
     https://iexcloud.io/docs/api/#k-score-for-us-equities
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_KAVOUT_KSCORE', symbol=symbol, **kwargs)
 
@@ -34,5 +37,8 @@ def kScoreDF(symbol='', **kwargs):
     '''Kavout takes in over 200 factors and signals including fundamentals, pricing, technical indicators, and alternative data, and then uses an ensemble machine learning technique to analyze and rank stocks.
     K Score is a stock rating and ranking score with values ranging from 1-to-9. A higher K Score (7-9) assigned to a stock indicates a higher probability of outperformance, whereas a lower K Score (1-3) indicates a lower probability of outperformance in the next month.
     https://iexcloud.io/docs/api/#k-score-for-us-equities
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_KAVOUT_KSCORE', symbol=symbol, **kwargs)
