@@ -24,6 +24,9 @@ def _baseDF(id, symbol='', **kwargs):
 def precisionAlphaPriceDynamics(symbol='', **kwargs):
     '''Precision Alpha performs an unbiased non-equilibrium market analysis on six months of closing price data for all NASDAQ and NYSE listed equities, every day after market close. Precision Alpha calculates scientifically and exactly: market emotion, power, resistance, noise/efficiency, and next day probabilities
     https://iexcloud.io/docs/api/#precision-alpha-price-dynamics
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_PRECISION_ALPHA_PRICE_DYNAMICS', symbol=symbol, **kwargs)
 
@@ -32,5 +35,8 @@ def precisionAlphaPriceDynamics(symbol='', **kwargs):
 def precisionAlphaPriceDynamicsDF(symbol='', **kwargs):
     '''Precision Alpha performs an unbiased non-equilibrium market analysis on six months of closing price data for all NASDAQ and NYSE listed equities, every day after market close. Precision Alpha calculates scientifically and exactly: market emotion, power, resistance, noise/efficiency, and next day probabilities
     https://iexcloud.io/docs/api/#precision-alpha-price-dynamics
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_PRECISION_ALPHA_PRICE_DYNAMICS', symbol=symbol, **kwargs)
