@@ -25,6 +25,9 @@ def analystDays(symbol='', **kwargs):
     '''This is a meeting where company executives provide information about the company’s performance and its future prospects.
 
     https://iexcloud.io/docs/api/#analyst-days
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_ANALYST_DAY', symbol=symbol, **kwargs)
 
@@ -34,6 +37,9 @@ def analystDaysDF(symbol='', **kwargs):
     '''This is a meeting where company executives provide information about the company’s performance and its future prospects.
 
     https://iexcloud.io/docs/api/#analyst-days
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_ANALYST_DAY', symbol=symbol, **kwargs)
 
@@ -42,6 +48,9 @@ def analystDaysDF(symbol='', **kwargs):
 def boardOfDirectorsMeeting(symbol='', **kwargs):
     '''This is an end-point for getting information about a formal meeting of a company’s board of directors to establish corporate management related policies and to make decisions on major company issues.
     https://iexcloud.io/docs/api/#analyst-days
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_BOARD_OF_DIRECTORS_MEETING', symbol=symbol, **kwargs)
 
@@ -50,6 +59,9 @@ def boardOfDirectorsMeeting(symbol='', **kwargs):
 def boardOfDirectorsMeetingDF(symbol='', **kwargs):
     '''This is a meeting where company executives provide information about the company’s performance and its future prospects.
     https://iexcloud.io/docs/api/#board-of-directors-meeting
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_BOARD_OF_DIRECTORS_MEETING', symbol=symbol, **kwargs)
 
@@ -58,6 +70,9 @@ def boardOfDirectorsMeetingDF(symbol='', **kwargs):
 def businessUpdates(symbol='', **kwargs):
     '''This is a meeting orconference call in which company information is reviewed by one or more company executives.
     https://iexcloud.io/docs/api/#business-updates
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_BUSINESS_UPDATE', symbol=symbol, **kwargs)
 
@@ -66,6 +81,9 @@ def businessUpdates(symbol='', **kwargs):
 def businessUpdatesDF(symbol='', **kwargs):
     '''This is a meeting orconference call in which company information is reviewed by one or more company executives.
     https://iexcloud.io/docs/api/#business-updates
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_BUSINESS_UPDATE', symbol=symbol, **kwargs)
 
@@ -74,6 +92,9 @@ def businessUpdatesDF(symbol='', **kwargs):
 def buybacks(symbol='', **kwargs):
     '''The repurchase of outstanding shares by a company to reduce the number of shares on the market.
     https://iexcloud.io/docs/api/#buybacks
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_BUYBACK', symbol=symbol, **kwargs)
 
@@ -82,6 +103,9 @@ def buybacks(symbol='', **kwargs):
 def buybacksDF(symbol='', **kwargs):
     '''The repurchase of outstanding shares by a company to reduce the number of shares on the market.
     https://iexcloud.io/docs/api/#buybacks
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_BUYBACK', symbol=symbol, **kwargs)
 
@@ -90,6 +114,9 @@ def buybacksDF(symbol='', **kwargs):
 def capitalMarketsDay(symbol='', **kwargs):
     '''This is a meeting where company executives provide information about the company’s performance and its future prospects.
     https://iexcloud.io/docs/api/#capital-markets-day
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_CAPITAL_MARKETS_DAY', symbol=symbol, **kwargs)
 
@@ -98,6 +125,9 @@ def capitalMarketsDay(symbol='', **kwargs):
 def capitalMarketsDayDF(symbol='', **kwargs):
     '''This is a meeting where company executives provide information about the company’s performance and its future prospects.
     https://iexcloud.io/docs/api/#capital-markets-day
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_CAPITAL_MARKETS_DAY', symbol=symbol, **kwargs)
 
@@ -106,6 +136,9 @@ def capitalMarketsDayDF(symbol='', **kwargs):
 def companyTravel(symbol='', **kwargs):
     '''This is a roadshow or bus tour event in which one or more company executives speaks to interested investors and analysts.
     https://iexcloud.io/docs/api/#company-travel
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_COMPANY_TRAVEL', symbol=symbol, **kwargs)
 
@@ -114,6 +147,9 @@ def companyTravel(symbol='', **kwargs):
 def companyTravelDF(symbol='', **kwargs):
     '''This is a roadshow or bus tour event in which one or more company executives speaks to interested investors and analysts.
     https://iexcloud.io/docs/api/#company-travel
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_COMPANY_TRAVEL', symbol=symbol, **kwargs)
 
@@ -122,6 +158,9 @@ def companyTravelDF(symbol='', **kwargs):
 def filingDueDates(symbol='', **kwargs):
     '''This is an estimated date, based on historical trends for this company in which a company must file the appropriate Form for the quarter/year or file for an extension.
     https://iexcloud.io/docs/api/#filing-due-dates
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_FILING_DUE_DATE', symbol=symbol, **kwargs)
 
@@ -130,6 +169,9 @@ def filingDueDates(symbol='', **kwargs):
 def filingDueDatesDF(symbol='', **kwargs):
     '''This is an estimated date, based on historical trends for this company in which a company must file the appropriate Form for the quarter/year or file for an extension.
     https://iexcloud.io/docs/api/#filing-due-dates
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_FILING_DUE_DATE', symbol=symbol, **kwargs)
 
@@ -138,6 +180,9 @@ def filingDueDatesDF(symbol='', **kwargs):
 def fiscalQuarterEnd(symbol='', **kwargs):
     '''This is a forecasted quarterly ending announcement date for a company. This may or may not correspond to a calendar quarter.
     https://iexcloud.io/docs/api/#fiscal-quarter-end
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_FISCAL_QUARTER_END_DATE', symbol=symbol, **kwargs)
 
@@ -146,6 +191,9 @@ def fiscalQuarterEnd(symbol='', **kwargs):
 def fiscalQuarterEndDF(symbol='', **kwargs):
     '''This is a forecasted quarterly ending announcement date for a company. This may or may not correspond to a calendar quarter.
     https://iexcloud.io/docs/api/#fiscal-quarter-end
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_FISCAL_QUARTER_END_DATE', symbol=symbol, **kwargs)
 
@@ -154,6 +202,9 @@ def fiscalQuarterEndDF(symbol='', **kwargs):
 def forum(symbol='', **kwargs):
     '''This is a meeting where ideas and views of a business nature can be exchanged.
     https://iexcloud.io/docs/api/#forum
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_FORUM', symbol=symbol, **kwargs)
 
@@ -162,6 +213,9 @@ def forum(symbol='', **kwargs):
 def forumDF(symbol='', **kwargs):
     '''This is a meeting where ideas and views of a business nature can be exchanged.
     https://iexcloud.io/docs/api/#forum
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_FORUM', symbol=symbol, **kwargs)
 
@@ -170,6 +224,9 @@ def forumDF(symbol='', **kwargs):
 def generalConference(symbol='', **kwargs):
     '''This is a formal meeting in which representatives of many companies gather to discuss ideas or issues related to a particular topic or business, usually held for several days. This item indicates at least one representative from the company will be presenting at the conference on the specified date and time. Note: Conference details include full Conference dates.
     https://iexcloud.io/docs/api/#general-conference
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_GENERAL_CONFERENCE', symbol=symbol, **kwargs)
 
@@ -178,6 +235,9 @@ def generalConference(symbol='', **kwargs):
 def generalConferenceDF(symbol='', **kwargs):
     '''This is a formal meeting in which representatives of many companies gather to discuss ideas or issues related to a particular topic or business, usually held for several days. This item indicates at least one representative from the company will be presenting at the conference on the specified date and time. Note: Conference details include full Conference dates.
     https://iexcloud.io/docs/api/#general-conference
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_GENERAL_CONFERENCE', symbol=symbol, **kwargs)
 
@@ -186,6 +246,9 @@ def generalConferenceDF(symbol='', **kwargs):
 def fdaAdvisoryCommitteeMeetings(symbol='', **kwargs):
     '''The FDA uses 50 committees and panels to obtain independent expert advice on scientific, technical, and policy matters
     https://iexcloud.io/docs/api/#fda-advisory-committee-meetings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_STOCK_SPECIFIC_FDA_ADVISORY_COMMITTEE_MEETING', symbol=symbol, **kwargs)
 
@@ -194,6 +257,9 @@ def fdaAdvisoryCommitteeMeetings(symbol='', **kwargs):
 def fdaAdvisoryCommitteeMeetingsDF(symbol='', **kwargs):
     '''The FDA uses 50 committees and panels to obtain independent expert advice on scientific, technical, and policy matters
     https://iexcloud.io/docs/api/#fda-advisory-committee-meetings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_STOCK_SPECIFIC_FDA_ADVISORY_COMMITTEE_MEETING', symbol=symbol, **kwargs)
 
@@ -202,6 +268,9 @@ def fdaAdvisoryCommitteeMeetingsDF(symbol='', **kwargs):
 def holidaysWSH(symbol='', **kwargs):
     '''This returns a list of market holidays.
     https://iexcloud.io/docs/api/#holidays
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_HOLIDAYS', symbol=symbol, **kwargs)
 
@@ -210,6 +279,9 @@ def holidaysWSH(symbol='', **kwargs):
 def holidaysWSHDF(symbol='', **kwargs):
     '''This returns a list of market holidays.
     https://iexcloud.io/docs/api/#holidays
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_HOLIDAYS', symbol=symbol, **kwargs)
 
@@ -218,6 +290,9 @@ def holidaysWSHDF(symbol='', **kwargs):
 def indexChanges(symbol='', **kwargs):
     '''This shows additions and removals from various indexes for particular stocks.
     https://iexcloud.io/docs/api/#index-changes
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_INDEX_CHANGE', symbol=symbol, **kwargs)
 
@@ -226,6 +301,9 @@ def indexChanges(symbol='', **kwargs):
 def indexChangesDF(symbol='', **kwargs):
     '''This shows additions and removals from various indexes for particular stocks.
     https://iexcloud.io/docs/api/#index-changes
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_INDEX_CHANGE', symbol=symbol, **kwargs)
 
@@ -234,6 +312,9 @@ def indexChangesDF(symbol='', **kwargs):
 def iposWSH(symbol='', **kwargs):
     '''Get a list of upcoming IPOs.
     https://iexcloud.io/docs/api/#ipos
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_INITIAL_PUBLIC_OFFERING', symbol=symbol, **kwargs)
 
@@ -242,6 +323,9 @@ def iposWSH(symbol='', **kwargs):
 def iposWSHDF(symbol='', **kwargs):
     '''Get a list of upcoming IPOs.
     https://iexcloud.io/docs/api/#ipos
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_INITIAL_PUBLIC_OFFERING', symbol=symbol, **kwargs)
 
@@ -250,6 +334,9 @@ def iposWSHDF(symbol='', **kwargs):
 def legalActions(symbol='', **kwargs):
     '''These are legal actions where an individual represents a group in a court claim. The judgment from the suit is for all the members of the group or class.
     https://iexcloud.io/docs/api/#legal-actions
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_LEGAL_ACTIONS', symbol=symbol, **kwargs)
 
@@ -258,6 +345,9 @@ def legalActions(symbol='', **kwargs):
 def legalActionsDF(symbol='', **kwargs):
     '''These are legal actions where an individual represents a group in a court claim. The judgment from the suit is for all the members of the group or class.
     https://iexcloud.io/docs/api/#legal-actions
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_LEGAL_ACTIONS', symbol=symbol, **kwargs)
 
@@ -266,6 +356,9 @@ def legalActionsDF(symbol='', **kwargs):
 def mergersAndAcquisitions(symbol='', **kwargs):
     '''These are a type of corporate action in which two companies combine to form a single company, or one company is taken over by another.
     https://iexcloud.io/docs/api/#mergers-acquisitions
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_MERGER_ACQUISITIONS', symbol=symbol, **kwargs)
 
@@ -274,6 +367,9 @@ def mergersAndAcquisitions(symbol='', **kwargs):
 def mergersAndAcquisitionsDF(symbol='', **kwargs):
     '''These are a type of corporate action in which two companies combine to form a single company, or one company is taken over by another.
     https://iexcloud.io/docs/api/#mergers-acquisitions
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_MERGER_ACQUISITIONS', symbol=symbol, **kwargs)
 
@@ -282,6 +378,9 @@ def mergersAndAcquisitionsDF(symbol='', **kwargs):
 def productEvents(symbol='', **kwargs):
     '''Represents movie and video releases. This is the date on which a movie distributor plans to release a movie to theaters
     https://iexcloud.io/docs/api/#product-events
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_PRODUCT_EVENTS', symbol=symbol, **kwargs)
 
@@ -290,6 +389,9 @@ def productEvents(symbol='', **kwargs):
 def productEventsDF(symbol='', **kwargs):
     '''Represents movie and video releases. This is the date on which a movie distributor plans to release a movie to theaters
     https://iexcloud.io/docs/api/#product-events
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_PRODUCT_EVENTS', symbol=symbol, **kwargs)
 
@@ -298,6 +400,9 @@ def productEventsDF(symbol='', **kwargs):
 def researchAndDevelopmentDays(symbol='', **kwargs):
     '''This is a day in which investors and analysts can meet with a company’s R&D representatives to learn more about new or improved products and services.
     https://iexcloud.io/docs/api/#research-and-development-days
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_RD_DAY', symbol=symbol, **kwargs)
 
@@ -306,6 +411,9 @@ def researchAndDevelopmentDays(symbol='', **kwargs):
 def researchAndDevelopmentDaysDF(symbol='', **kwargs):
     '''This is a day in which investors and analysts can meet with a company’s R&D representatives to learn more about new or improved products and services.
     https://iexcloud.io/docs/api/#research-and-development-days
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_RD_DAY', symbol=symbol, **kwargs)
 
@@ -314,6 +422,9 @@ def researchAndDevelopmentDaysDF(symbol='', **kwargs):
 def sameStoreSales(symbol='', **kwargs):
     '''Same-store sales, also referred to as comparable-store sales, SSS or identical-store sales, is a financial metric that companies in the retail industry use to evaluate the total dollar amount of sales in the company’s stores that have been operating for a year or more.
     https://iexcloud.io/docs/api/#same-store-sales
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_SAME_STORE_SALES', symbol=symbol, **kwargs)
 
@@ -322,6 +433,9 @@ def sameStoreSales(symbol='', **kwargs):
 def sameStoreSalesDF(symbol='', **kwargs):
     '''Same-store sales, also referred to as comparable-store sales, SSS or identical-store sales, is a financial metric that companies in the retail industry use to evaluate the total dollar amount of sales in the company’s stores that have been operating for a year or more.
     https://iexcloud.io/docs/api/#same-store-sales
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_SAME_STORE_SALES', symbol=symbol, **kwargs)
 
@@ -333,6 +447,9 @@ def secondaryOfferings(symbol='', **kwargs):
     Money raised from these kinds of secondary offerings goes to the company, through the investment bank that underwrites the offering.
     Investment banks are issued an allotment, and possibly an overallotment which they may choose to exercise if there is a strong possibility of making money on the spread between the allotment price and the selling price of the securities. Short Selling is prohibited during the period of the secondary offering.
     https://iexcloud.io/docs/api/#secondary-offerings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_SECONDARY_OFFERING', symbol=symbol, **kwargs)
 
@@ -344,6 +461,9 @@ def secondaryOfferingsDF(symbol='', **kwargs):
     Money raised from these kinds of secondary offerings goes to the company, through the investment bank that underwrites the offering.
     Investment banks are issued an allotment, and possibly an overallotment which they may choose to exercise if there is a strong possibility of making money on the spread between the allotment price and the selling price of the securities. Short Selling is prohibited during the period of the secondary offering.
     https://iexcloud.io/docs/api/#secondary-offerings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_SECONDARY_OFFERING', symbol=symbol, **kwargs)
 
@@ -352,6 +472,9 @@ def secondaryOfferingsDF(symbol='', **kwargs):
 def seminars(symbol='', **kwargs):
     '''This is an educational event that features one or more subject matter experts delivering information via lecture and discussion.
     https://iexcloud.io/docs/api/#seminars
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_SEMINAR', symbol=symbol, **kwargs)
 
@@ -360,6 +483,9 @@ def seminars(symbol='', **kwargs):
 def seminarsDF(symbol='', **kwargs):
     '''This is an educational event that features one or more subject matter experts delivering information via lecture and discussion.
     https://iexcloud.io/docs/api/#seminars
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_SEMINAR', symbol=symbol, **kwargs)
 
@@ -368,6 +494,9 @@ def seminarsDF(symbol='', **kwargs):
 def shareholderMeetings(symbol='', **kwargs):
     '''This is a meeting, held at least annually, to elect members to the board of directors and hear reports on the business’ financial situation as well as new policy initiatives from the corporation’s management.
     https://iexcloud.io/docs/api/#shareholder-meetings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_SHAREHOLDER_MEETING', symbol=symbol, **kwargs)
 
@@ -376,6 +505,9 @@ def shareholderMeetings(symbol='', **kwargs):
 def shareholderMeetingsDF(symbol='', **kwargs):
     '''This is a meeting, held at least annually, to elect members to the board of directors and hear reports on the business’ financial situation as well as new policy initiatives from the corporation’s management.
     https://iexcloud.io/docs/api/#shareholder-meetings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_SHAREHOLDER_MEETING', symbol=symbol, **kwargs)
 
@@ -384,6 +516,9 @@ def shareholderMeetingsDF(symbol='', **kwargs):
 def summitMeetings(symbol='', **kwargs):
     '''This is a gathering of people who are interested in the same business subject or topic.
     https://iexcloud.io/docs/api/#summit-meetings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_SUMMIT_MEETING', symbol=symbol, **kwargs)
 
@@ -392,6 +527,9 @@ def summitMeetings(symbol='', **kwargs):
 def summitMeetingsDF(symbol='', **kwargs):
     '''This is a gathering of people who are interested in the same business subject or topic.
     https://iexcloud.io/docs/api/#summit-meetings
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_SUMMIT_MEETING', symbol=symbol, **kwargs)
 
@@ -400,6 +538,9 @@ def summitMeetingsDF(symbol='', **kwargs):
 def tradeShows(symbol='', **kwargs):
     '''This is a large gathering in which different companies in a particular field or industry show their products to possible customers.
     https://iexcloud.io/docs/api/#trade-shows
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_TRADE_SHOW', symbol=symbol, **kwargs)
 
@@ -408,6 +549,9 @@ def tradeShows(symbol='', **kwargs):
 def tradeShowsDF(symbol='', **kwargs):
     '''This is a large gathering in which different companies in a particular field or industry show their products to possible customers.
     https://iexcloud.io/docs/api/#trade-shows
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_TRADE_SHOW', symbol=symbol, **kwargs)
 
@@ -416,6 +560,9 @@ def tradeShowsDF(symbol='', **kwargs):
 def witchingHours(symbol='', **kwargs):
     '''This is when option contracts and futures contracts expire on the exact same day.
     https://iexcloud.io/docs/api/#witching-hours
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_WITCHING_HOURS', symbol=symbol, **kwargs)
 
@@ -424,6 +571,9 @@ def witchingHours(symbol='', **kwargs):
 def witchingHoursDF(symbol='', **kwargs):
     '''This is when option contracts and futures contracts expire on the exact same day.
     https://iexcloud.io/docs/api/#witching-hours
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_WITCHING_HOURS', symbol=symbol, **kwargs)
 
@@ -432,6 +582,9 @@ def witchingHoursDF(symbol='', **kwargs):
 def workshops(symbol='', **kwargs):
     '''This is a meeting or series of meetings at which a group of people engage in discussion and activity on a particular subject, product or service to gain hands-on experience.
     https://iexcloud.io/docs/api/#workshops
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _base(id='PREMIUM_WALLSTREETHORIZON_WORKSHOP', symbol=symbol, **kwargs)
 
@@ -440,5 +593,8 @@ def workshops(symbol='', **kwargs):
 def workshopsDF(symbol='', **kwargs):
     '''This is a meeting or series of meetings at which a group of people engage in discussion and activity on a particular subject, product or service to gain hands-on experience.
     https://iexcloud.io/docs/api/#workshops
+
+    Args:
+        symbol (str); symbol to use
     '''
     return _baseDF(id='PREMIUM_WALLSTREETHORIZON_WORKSHOP', symbol=symbol, **kwargs)
