@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
+from functools import wraps
 import pandas as pd
 import numpy as np
-from ..common import _expire, _TIMEFRAME_DIVSPLIT, _getJson, _raiseIfNotStr, PyEXception, _reindex, _toDatetime, _UTC
+from ..common import _expire, _TIMEFRAME_DIVSPLIT, _getJson, _raiseIfNotStr, PyEXception, _reindex, _toDatetime, _checkPeriodLast, _UTC
 
 
 @_expire(hour=8, tz=_UTC)
-def balanceSheet(symbol, token='', version='', filter=''):
+def balanceSheet(symbol, period='quarter', last=1, token='', version='', filter=''):
     '''Pulls balance sheet data. Available quarterly (4 quarters) and annually (4 years)
 
     https://iexcloud.io/docs/api/#balance-sheet
@@ -14,34 +15,23 @@ def balanceSheet(symbol, token='', version='', filter=''):
 
     Args:
         symbol (string); Ticker to request
+        period (string); Period, either 'annual' or 'quarter'
+        last (int); Number of records to fetch, up to 12 for 'quarter' and 4 for 'annual'
         token (string); Access token
         version (string); API version
         filter (string); filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/balance-sheet', token, version, filter)
+    _checkPeriodLast(period, last)
+    return _getJson('stock/{}/balance-sheet?period={}&last={}'.format(symbol, period, last), token, version, filter)
 
 
-def balanceSheetDF(symbol, token='', version='', filter=''):
-    '''Pulls balance sheet data. Available quarterly (4 quarters) and annually (4 years)
-
-    https://iexcloud.io/docs/api/#balance-sheet
-    Updates at 8am, 9am UTC daily
-
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
-    val = balanceSheet(symbol, token, version, filter)
+@wraps(balanceSheet)
+def balanceSheetDF(symbol, period='quarter', last=1, token='', version='', filter=''):
+    val = balanceSheet(symbol, period, last, token, version, filter)
     df = pd.io.json.json_normalize(val, 'balancesheet', 'symbol')
     _toDatetime(df)
     _reindex(df, 'reportDate')
@@ -49,7 +39,7 @@ def balanceSheetDF(symbol, token='', version='', filter=''):
 
 
 @_expire(hour=8, tz=_UTC)
-def cashFlow(symbol, token='', version='', filter=''):
+def cashFlow(symbol, period='quarter', last=1, token='', version='', filter=''):
     '''Pulls cash flow data. Available quarterly (4 quarters) or annually (4 years).
 
     https://iexcloud.io/docs/api/#cash-flow
@@ -58,34 +48,23 @@ def cashFlow(symbol, token='', version='', filter=''):
 
     Args:
         symbol (string); Ticker to request
+        period (string); Period, either 'annual' or 'quarter'
+        last (int); Number of records to fetch, up to 12 for 'quarter' and 4 for 'annual'
         token (string); Access token
         version (string); API version
         filter (string); filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/cash-flow', token, version, filter)
+    _checkPeriodLast(period, last)
+    return _getJson('stock/{}/cash-flow?period={}&last={}'.format(symbol, period, last), token, version, filter)
 
 
-def cashFlowDF(symbol, token='', version='', filter=''):
-    '''Pulls cash flow data. Available quarterly (4 quarters) or annually (4 years).
-
-    https://iexcloud.io/docs/api/#cash-flow
-    Updates at 8am, 9am UTC daily
-
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
-    val = cashFlow(symbol, token, version, filter)
+@wraps(cashFlow)
+def cashFlowDF(symbol, period='quarter', last=1, token='', version='', filter=''):
+    val = cashFlow(symbol, period, last, token, version, filter)
     df = pd.io.json.json_normalize(val, 'cashflow', 'symbol')
     _toDatetime(df)
     _reindex(df, 'reportDate')
@@ -107,7 +86,7 @@ def dividends(symbol, timeframe='ytd', token='', version='', filter=''):
         filter (string); filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     if timeframe not in _TIMEFRAME_DIVSPLIT:
@@ -123,28 +102,15 @@ def _dividendsToDF(d):
     return df
 
 
+@wraps(dividends)
 def dividendsDF(symbol, timeframe='ytd', token='', version='', filter=''):
-    '''Dividend history
-
-    https://iexcloud.io/docs/api/#dividends
-    Updated at 9am UTC every day
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     d = dividends(symbol, timeframe, token, version, filter)
     df = _dividendsToDF(d)
     return df
 
 
 @_expire(hour=9, tz=_UTC)
-def earnings(symbol, token='', version='', filter=''):
+def earnings(symbol, period='quarter', last=1, field='', token='', version='', filter=''):
     '''Earnings data for a given company including the actual EPS, consensus, and fiscal period. Earnings are available quarterly (last 4 quarters) and annually (last 4 years).
 
     https://iexcloud.io/docs/api/#earnings
@@ -152,15 +118,20 @@ def earnings(symbol, token='', version='', filter=''):
 
     Args:
         symbol (string); Ticker to request
+        period (string); Period, either 'annual' or 'quarter'
+        last (int); Number of records to fetch, up to 12 for 'quarter' and 4 for 'annual'
         token (string); Access token
         version (string); API version
         filter (string); filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/earnings', token, version, filter)
+    _checkPeriodLast(period, last)
+    if not field:
+        return _getJson('stock/{}/earnings?period={}&last={}'.format(symbol, period, last), token, version, filter)
+    return _getJson('stock/{}/earnings/{}/{}?period={}'.format(symbol, last, field, period), token, version, filter)
 
 
 def _earningsToDF(e):
@@ -174,28 +145,15 @@ def _earningsToDF(e):
     return df
 
 
-def earningsDF(symbol, token='', version='', filter=''):
-    '''Earnings data for a given company including the actual EPS, consensus, and fiscal period. Earnings are available quarterly (last 4 quarters) and annually (last 4 years).
-
-    https://iexcloud.io/docs/api/#earnings
-    Updates at 9am, 11am, 12pm UTC every day
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
-    e = earnings(symbol, token, version, filter)
+@wraps(earnings)
+def earningsDF(symbol, period='quarter', last=1, field='', token='', version='', filter=''):
+    e = earnings(symbol, period, last, field, token, version, filter)
     df = _earningsToDF(e)
     return df
 
 
 @_expire(hour=8, tz=_UTC)
-def financials(symbol, token='', version='', filter=''):
+def financials(symbol, period='quarter', token='', version='', filter=''):
     '''Pulls income statement, balance sheet, and cash flow data from the four most recent reported quarters.
 
     https://iexcloud.io/docs/api/#financials
@@ -203,15 +161,17 @@ def financials(symbol, token='', version='', filter=''):
 
     Args:
         symbol (string); Ticker to request
+        period (string); Period, either 'annual' or 'quarter'
         token (string); Access token
         version (string); API version
         filter (string); filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/financials', token, version, filter)
+    _checkPeriodLast(period, 1)
+    return _getJson('stock/{}/financials?period={}'.format(symbol, period), token, version, filter)
 
 
 def _financialsToDF(f):
@@ -225,28 +185,15 @@ def _financialsToDF(f):
     return df
 
 
-def financialsDF(symbol, token='', version='', filter=''):
-    '''Pulls income statement, balance sheet, and cash flow data from the four most recent reported quarters.
-
-    https://iexcloud.io/docs/api/#financials
-    Updates at 8am, 9am UTC daily
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
-    f = financials(symbol, token, version, filter)
+@wraps(financials)
+def financialsDF(symbol, period='quarter', token='', version='', filter=''):
+    f = financials(symbol, period, token, version, filter)
     df = _financialsToDF(f)
     return df
 
 
 @_expire(hour=8, tz=_UTC)
-def incomeStatement(symbol, token='', version='', filter=''):
+def incomeStatement(symbol, period='quarter', last=1, token='', version='', filter=''):
     '''Pulls income statement data. Available quarterly (4 quarters) or annually (4 years).
 
     https://iexcloud.io/docs/api/#income-statement
@@ -254,33 +201,23 @@ def incomeStatement(symbol, token='', version='', filter=''):
 
     Args:
         symbol (string); Ticker to request
+        period (string); Period, either 'annual' or 'quarter'
+        last (int); Number of records to fetch, up to 12 for 'quarter' and 4 for 'annual'
         token (string); Access token
         version (string); API version
         filter (string); filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/income', token, version, filter)
+    _checkPeriodLast(period, last)
+    return _getJson('stock/{}/income?period={}&last={}'.format(symbol, period, last), token, version, filter)
 
 
-def incomeStatementDF(symbol, token='', version='', filter=''):
-    '''Pulls income statement data. Available quarterly (4 quarters) or annually (4 years).
-
-    https://iexcloud.io/docs/api/#income-statement
-    Updates at 8am, 9am UTC daily
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
-    val = incomeStatement(symbol, token, version, filter)
+@wraps(incomeStatement)
+def incomeStatementDF(symbol, period='quarter', last=1, token='', version='', filter=''):
+    val = incomeStatement(symbol, period, last, token, version, filter)
     df = pd.io.json.json_normalize(val, 'income', 'symbol')
     _toDatetime(df)
     _reindex(df, 'reportDate')
@@ -301,7 +238,7 @@ def stockSplits(symbol, timeframe='ytd', token='', version='', filter=''):
         filter (string); filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     if timeframe not in _TIMEFRAME_DIVSPLIT:
@@ -317,21 +254,8 @@ def _splitsToDF(s):
     return df
 
 
+@wraps(stockSplits)
 def stockSplitsDF(symbol, timeframe='ytd', token='', version='', filter=''):
-    '''Stock split history
-
-    https://iexcloud.io/docs/api/#splits
-    Updated at 9am UTC every day
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     s = stockSplits(symbol, timeframe, token, version, filter)
     df = _splitsToDF(s)
     return df
